#[non_exhaustive]pub struct StartMedicalScribeStreamInput {
pub session_id: Option<String>,
pub language_code: Option<MedicalScribeLanguageCode>,
pub media_sample_rate_hertz: Option<i32>,
pub media_encoding: Option<MedicalScribeMediaEncoding>,
pub input_stream: EventStreamSender<MedicalScribeInputStream, MedicalScribeInputStreamError>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: Option<String>Specify an identifier for your streaming session (in UUID format). If you don't include a SessionId in your request, Amazon Web Services HealthScribe generates an ID and returns it in the response.
language_code: Option<MedicalScribeLanguageCode>Specify the language code for your HealthScribe streaming session.
media_sample_rate_hertz: Option<i32>Specify the sample rate of the input audio (in hertz). Amazon Web Services HealthScribe supports a range from 16,000 Hz to 48,000 Hz. The sample rate you specify must match that of your audio.
media_encoding: Option<MedicalScribeMediaEncoding>Specify the encoding used for the input audio.
Supported formats are:
-
FLAC
-
OPUS-encoded audio in an Ogg container
-
PCM (only signed 16-bit little-endian audio formats, which does not include WAV)
For more information, see Media formats.
input_stream: EventStreamSender<MedicalScribeInputStream, MedicalScribeInputStreamError>Specify the input stream where you will send events in real time.
The first element of the input stream must be a MedicalScribeConfigurationEvent.
Implementations
Sourceimpl StartMedicalScribeStreamInput
impl StartMedicalScribeStreamInput
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
Specify an identifier for your streaming session (in UUID format). If you don't include a SessionId in your request, Amazon Web Services HealthScribe generates an ID and returns it in the response.
Sourcepub fn language_code(&self) -> Option<&MedicalScribeLanguageCode>
pub fn language_code(&self) -> Option<&MedicalScribeLanguageCode>
Specify the language code for your HealthScribe streaming session.
Sourcepub fn media_sample_rate_hertz(&self) -> Option<i32>
pub fn media_sample_rate_hertz(&self) -> Option<i32>
Specify the sample rate of the input audio (in hertz). Amazon Web Services HealthScribe supports a range from 16,000 Hz to 48,000 Hz. The sample rate you specify must match that of your audio.
Sourcepub fn media_encoding(&self) -> Option<&MedicalScribeMediaEncoding>
pub fn media_encoding(&self) -> Option<&MedicalScribeMediaEncoding>
Specify the encoding used for the input audio.
Supported formats are:
-
FLAC
-
OPUS-encoded audio in an Ogg container
-
PCM (only signed 16-bit little-endian audio formats, which does not include WAV)
For more information, see Media formats.
Sourcepub fn input_stream(
&self,
) -> &EventStreamSender<MedicalScribeInputStream, MedicalScribeInputStreamError>
pub fn input_stream( &self, ) -> &EventStreamSender<MedicalScribeInputStream, MedicalScribeInputStreamError>
Specify the input stream where you will send events in real time.
The first element of the input stream must be a MedicalScribeConfigurationEvent.
Sourceimpl StartMedicalScribeStreamInput
impl StartMedicalScribeStreamInput
Sourcepub fn deserialize(
deserializer: &mut dyn ShapeDeserializer,
) -> Result<Self, SerdeError>
pub fn deserialize( deserializer: &mut dyn ShapeDeserializer, ) -> Result<Self, SerdeError>
Deserializes this structure from a [ShapeDeserializer].
Sourceimpl StartMedicalScribeStreamInput
impl StartMedicalScribeStreamInput
Sourcepub fn deserialize_with_response(
deserializer: &mut dyn ShapeDeserializer,
headers: &Headers,
_status: u16,
_body: &[u8],
) -> Result<Self, SerdeError>
pub fn deserialize_with_response( deserializer: &mut dyn ShapeDeserializer, headers: &Headers, _status: u16, _body: &[u8], ) -> Result<Self, SerdeError>
Deserializes this structure from a body deserializer and HTTP response headers. Header-bound members are read directly from headers, avoiding runtime member iteration overhead. Body members are read via the deserializer.
Sourceimpl StartMedicalScribeStreamInput
impl StartMedicalScribeStreamInput
Sourcepub fn builder() -> StartMedicalScribeStreamInputBuilder
pub fn builder() -> StartMedicalScribeStreamInputBuilder
Creates a new builder-style object to manufacture StartMedicalScribeStreamInput.