#[non_exhaustive]pub struct StartMedicalStreamTranscriptionOutput {Show 13 fields
pub request_id: Option<String>,
pub language_code: Option<LanguageCode>,
pub media_sample_rate_hertz: Option<i32>,
pub media_encoding: Option<MediaEncoding>,
pub vocabulary_name: Option<String>,
pub specialty: Option<Specialty>,
pub type: Option<Type>,
pub show_speaker_label: bool,
pub session_id: Option<String>,
pub transcript_result_stream: EventReceiver<MedicalTranscriptResultStream, MedicalTranscriptResultStreamError>,
pub enable_channel_identification: bool,
pub number_of_channels: Option<i32>,
pub content_identification_type: Option<MedicalContentIdentificationType>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: Option<String>Provides the identifier for your streaming request.
language_code: Option<LanguageCode>Provides the language code that you specified in your request. This must be en-US.
media_sample_rate_hertz: Option<i32>Provides the sample rate that you specified in your request.
media_encoding: Option<MediaEncoding>Provides the media encoding you specified in your request.
vocabulary_name: Option<String>Provides the name of the custom vocabulary that you specified in your request.
specialty: Option<Specialty>Provides the medical specialty that you specified in your request.
type: Option<Type>Provides the type of audio you specified in your request.
show_speaker_label: boolShows whether speaker partitioning was enabled for your transcription.
session_id: Option<String>Provides the identifier for your transcription session.
transcript_result_stream: EventReceiver<MedicalTranscriptResultStream, MedicalTranscriptResultStreamError>Provides detailed information about your streaming session.
enable_channel_identification: boolShows whether channel identification was enabled for your transcription.
number_of_channels: Option<i32>Provides the number of channels that you specified in your request.
content_identification_type: Option<MedicalContentIdentificationType>Shows whether content identification was enabled for your transcription.
Implementations
Sourceimpl StartMedicalStreamTranscriptionOutput
impl StartMedicalStreamTranscriptionOutput
Sourcepub fn request_id(&self) -> Option<&str>
pub fn request_id(&self) -> Option<&str>
Provides the identifier for your streaming request.
Sourcepub fn language_code(&self) -> Option<&LanguageCode>
pub fn language_code(&self) -> Option<&LanguageCode>
Provides the language code that you specified in your request. This must be en-US.
Sourcepub fn media_sample_rate_hertz(&self) -> Option<i32>
pub fn media_sample_rate_hertz(&self) -> Option<i32>
Provides the sample rate that you specified in your request.
Sourcepub fn media_encoding(&self) -> Option<&MediaEncoding>
pub fn media_encoding(&self) -> Option<&MediaEncoding>
Provides the media encoding you specified in your request.
Sourcepub fn vocabulary_name(&self) -> Option<&str>
pub fn vocabulary_name(&self) -> Option<&str>
Provides the name of the custom vocabulary that you specified in your request.
Sourcepub fn specialty(&self) -> Option<&Specialty>
pub fn specialty(&self) -> Option<&Specialty>
Provides the medical specialty that you specified in your request.
Sourcepub fn show_speaker_label(&self) -> bool
pub fn show_speaker_label(&self) -> bool
Shows whether speaker partitioning was enabled for your transcription.
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
Provides the identifier for your transcription session.
Sourcepub fn transcript_result_stream(
&self,
) -> &EventReceiver<MedicalTranscriptResultStream, MedicalTranscriptResultStreamError>
pub fn transcript_result_stream( &self, ) -> &EventReceiver<MedicalTranscriptResultStream, MedicalTranscriptResultStreamError>
Provides detailed information about your streaming session.
Sourcepub fn enable_channel_identification(&self) -> bool
pub fn enable_channel_identification(&self) -> bool
Shows whether channel identification was enabled for your transcription.
Sourcepub fn number_of_channels(&self) -> Option<i32>
pub fn number_of_channels(&self) -> Option<i32>
Provides the number of channels that you specified in your request.
Sourcepub fn content_identification_type(
&self,
) -> Option<&MedicalContentIdentificationType>
pub fn content_identification_type( &self, ) -> Option<&MedicalContentIdentificationType>
Shows whether content identification was enabled for your transcription.
Sourceimpl StartMedicalStreamTranscriptionOutput
impl StartMedicalStreamTranscriptionOutput
Sourcepub fn deserialize(
deserializer: &mut dyn ShapeDeserializer,
) -> Result<Self, SerdeError>
pub fn deserialize( deserializer: &mut dyn ShapeDeserializer, ) -> Result<Self, SerdeError>
Deserializes this structure from a [ShapeDeserializer].
Sourceimpl StartMedicalStreamTranscriptionOutput
impl StartMedicalStreamTranscriptionOutput
Sourcepub fn deserialize_with_response(
deserializer: &mut dyn ShapeDeserializer,
headers: &Headers,
_status: u16,
_body: &[u8],
) -> Result<Self, SerdeError>
pub fn deserialize_with_response( deserializer: &mut dyn ShapeDeserializer, headers: &Headers, _status: u16, _body: &[u8], ) -> Result<Self, SerdeError>
Deserializes this structure from a body deserializer and HTTP response headers. Header-bound members are read directly from headers, avoiding runtime member iteration overhead. Body members are read via the deserializer.
Sourceimpl StartMedicalStreamTranscriptionOutput
impl StartMedicalStreamTranscriptionOutput
Sourcepub fn builder() -> StartMedicalStreamTranscriptionOutputBuilder
pub fn builder() -> StartMedicalStreamTranscriptionOutputBuilder
Creates a new builder-style object to manufacture StartMedicalStreamTranscriptionOutput.