pub struct DocumentTrait { /* private fields */ }Expand description
A trait with a Document value, used for unknown/custom traits.
When a trait is included in a schema but has no typed Rust representation,
its value is stored as a Document.
Implementations